Free Calorie Counter, Diet & Exercise Journal | MyFitnessPal.com
Description: Free online calorie counter and diet plan. Lose weight by tracking your caloric intake quickly and easily. Find nutrition facts for over 2,000,000 foods.
Keywords: calorie counter, free diet journal, weight loss program, nutrition facts, online calorie counter, free diet plan, weight loss online, free calorie counter

Calorie Counter

# Edit Previous Measurement Entries

Measurement to edit:

Starting Body Fat: on 1/13/2015

Measurement | Date | Amount | Delete?
« Prev 1 2 3 4 5 6 7 8 9 10 Next »
Body Fat | 4/29/2015 | 19.1 | Delete?
Body Fat | 4/28/2015 | 19.2 | Delete?
Body Fat | 4/27/2015 | 19.2 | Delete?
Body Fat | 4/26/2015 | 19 | Delete?
Body Fat | 4/25/2015 | 18.7 | Delete?
Body Fat | 4/23/2015 | 18.7 | Delete?
Body Fat | 4/22/2015 | 18.4 | Delete?
Body Fat | 4/21/2015 | 18.9 | Delete?
Body Fat | 4/20/2015 | 19.1 | Delete?
Body Fat | 4/19/2015 | 19.1 | Delete?

# Add New Entry

Date:
Amount:

## Member Login

- Log in with Facebook
- - or -
- Username:
- Password:
- Remember me next time
- Forgot password or username?
- Not a member yet? Sign up now!